/* ************************************************************************** *
 *      Copyright © IPSL/LSCE, XMLIOServer, Avril 2010 - Octobre 2011         *
 * ************************************************************************** */
/**
 * \file    main_server.cpp
 * \brief   Programme principal du projet.
 * \author  Hervé Ozdoba
 * \version 0.4
 * \date    1er Juin 2011
 *
 * Ce fichier contient le point d'entrée du programme permettant
 * de lancer le serveur d'Entrée/Sortie parallèle.
 */

// XMLIOServer headers
#include "xmlioserver_spl.hpp"

#include "inetcdf4.hpp"
#include "inetcdf4_impl.hpp"
#include "inetcdf4_adv.hpp"
#include "inetcdf4_adv_impl.hpp"
#include "lscereader.hpp"

namespace xios = xmlioserver;
//~ using namespace xios::data;
using namespace xios::io;
//~ using namespace xios::tree;
//~ using namespace xios::xml;
//~ using namespace xios::comm;
//~ using namespace xios::func;
using namespace xios::vtk;

// Point d'entrée du programme serveur principal.
int main (int XIOS_UNUSED (argc), char ** XIOS_UNUSED (argv), char ** XIOS_UNUSED (env))
{
   try
   {
       std::cout << "Test input"  << std::endl;
       CINetCDF4Adv file_coslatgrid("test/vtk/file_coslatgrid.nc4");
       CINetCDF4Adv file_xboundsybounds("test/vtk/file_xboundsybounds.nc4");
       CINetCDF4Adv sampleCurveGrid4("test/vtk/sampleCurveGrid4.nc4");
       CINetCDF4Adv sampleGenGrid3("test/vtk/sampleGenGrid3.nc4");
       CINetCDF4Adv ucov("test/vtk/ucov.nc4");
       
       std::vector<CINetCDF4Adv*> listinput;
       listinput.push_back(&file_coslatgrid);
       listinput.push_back(&file_xboundsybounds);
       listinput.push_back(&sampleCurveGrid4);
       listinput.push_back(&sampleGenGrid3);
       listinput.push_back(&ucov);
       std::vector<CINetCDF4Adv*>::iterator it = listinput.begin(), end = listinput.end();
       
       for (; it != end; it++)
       {
           std::cout << "-------------" << std::endl;
           std::map<std::string, std::size_t> dims = (*it)->getDimensions();
           std::map<std::string, std::size_t>::iterator it0 = dims.begin(), end0 = dims.end();
           
           for (; it0 != end0; it0++)
           {
               std::cout << "dimensions " << it0->first << " : " << it0->second << std::endl;
           }
           
           std::vector<std::string> vars = (*it)->getVariables();
           std::vector<std::string>::iterator it1 = vars.begin(), end1 = vars.end();
           for (; it1 != end1; it1++)
           {
               std::map<std::string, std::size_t> dims = (*it)->getDimensions(&(*it1));
               std::map<std::string, std::size_t>::iterator it3 = dims.begin(), end3 = dims.end();

               std::cout << "Variable " << *it1 << " [";
               for (; it3 != end3; it3++)
               {
                   std::cout << it3->first << ":" << it3->second << " ";
               }
               std::cout << "] :" << std::endl;
           }
       }
       
       boost::multi_array<float, 1> data;
       file_coslatgrid.readData(data, "NTEMP", 1);
       std::cout << data.size() << std::endl;

       
       //vtkLSCEReader::ShowVariable("test/vtk/file_coslatgrid.nc4", "NTEMP");
       vtkLSCEReader::ShowVariable("test/vtk/ucov.nc4", "ucov");
       //vtkLSCEReader::ShowVariable("test/vtk/sampleCurveGrid4.nc4", "sample");
       //vtkLSCEReader::ShowVariable("test/vtk/sampleGenGrid3.nc4", "sample");
       //vtkLSCEReader::ShowVariable("test/vtk/file_xboundsybounds.nc4", "A");
       

   }
   catch (xios::CException & _exception)
   {
      std::cerr << _exception.getMessage() << std::endl;
      return (-1);
   }
   return (0);
}


